@@ -66,16 +66,20 @@ def test_deal_action(cover_bot: CoverBot):
     assert cover_bot.deals[deal_buy["code"]].quantity == -1
 
 
-def test_deal_date(cover_bot: CoverBot):
+def test_deal_date(cover_bot: CoverBot, mocker):
+    mocker_place_order = mocker.patch.object(cover_bot.api.quote, "subscribe")
     cover_bot.order_handler(OrderState.TFTDeal, deal_buy)
+    mocker_place_order.assert_called_once()
     assert cover_bot.deals[deal_buy["code"]].quantity == 1
 
 
-def test_show(cover_bot: CoverBot, deal_data):
+def test_show(cover_bot: CoverBot, deal_data, mocker):
+    mocker_place_order = mocker.patch.object(cover_bot.api.quote, "subscribe")
+
     for deal in deal_data:
         if deal["action"] == "Sell":
             cover_bot.order_handler(OrderState.TFTDeal, deal)
-    logger.info(cover_bot.show())
+    # logger.info(cover_bot.show())
 
 
 def test_non_deal_quote_should_be_None(
@@ -83,7 +87,7 @@ def test_non_deal_quote_should_be_None(
 ):
     exchange, quote = quote_data
     result = cover_bot.quote_handler(exchange=exchange, quote=quote)  # type: ignore
-    assert result == None
+    assert result == False
 
 
 def test_coverbot_set_stop_loss_pct(cover_bot: CoverBot):
@@ -96,15 +100,21 @@ def test_coverbot_set_stop_loss_pct(cover_bot: CoverBot):
 
 
 def test_in_deal_quote_should_be_(
-    cover_bot: CoverBot, quote_data: Tuple[Exchange, QuoteSTKv1]
+    cover_bot: CoverBot, mock_api, quote_data: Tuple[Exchange, QuoteSTKv1], mocker
 ):
     cover_bot.deal_action(deal_sell)
     exchange, quote = quote_data
     quote.code = "5871"
+    mocker_place_order = mocker.patch.object(mock_api, "place_order")
+    result = cover_bot.quote_handler(exchange=exchange, quote=quote)  # type: ignore
+    mocker_place_order.assert_called_once()
+    assert result == True
+    result = cover_bot.quote_handler(exchange=exchange, quote=quote)  # type: ignore
+    result = cover_bot.quote_handler(exchange=exchange, quote=quote)  # type: ignore
     result = cover_bot.quote_handler(exchange=exchange, quote=quote)  # type: ignore
-    assert result == "place order sell"
 
 
-def test_tftorder(cover_bot: CoverBot):
+def test_tftorder(cover_bot: CoverBot, mocker):
+    mocker_place_order = mocker.patch.object(cover_bot.api.quote, "subscribe")
     tftorder = {"contract": {"code": "5871"}}
     cover_bot.order_handler(OrderState.TFTOrder, tftorder)
